package javax.management.monitor;

import javax.management.ObjectName;
import java.util.Iterator;
import java.util.logging.Level;
import com.sun.jmx.defaults.JmxProperties;
import javax.management.MBeanNotificationInfo;

public class StringMonitor extends Monitor implements StringMonitorMBean
{
    private String stringToCompare;
    private boolean notifyMatch;
    private boolean notifyDiffer;
    private static final String[] types;
    private static final MBeanNotificationInfo[] notifsInfo;
    private static final int MATCHING = 0;
    private static final int DIFFERING = 1;
    private static final int MATCHING_OR_DIFFERING = 2;
    
    public StringMonitor() {
        this.stringToCompare = "";
        this.notifyMatch = false;
        this.notifyDiffer = false;
    }
    
    @Override
    public synchronized void start() {
        if (this.isActive()) {
            JmxProperties.MONITOR_LOGGER.logp(Level.FINER, StringMonitor.class.getName(), "start", "the monitor is already active");
            return;
        }
        Iterator<Monitor.ObservedObject> iterator = this.observedObjects.iterator();
        while (iterator.hasNext()) {
            ((StringMonitor.StringMonitorObservedObject)(Monitor.ObservedObject)iterator.next()).setStatus(2);
        }
        this.doStart();
        return;
    }
    
    @Override
    public synchronized void stop() {
        this.doStop();
    }
    
    @Override
    public synchronized String getDerivedGauge(ObjectName objectName) {
        return (String)super.getDerivedGauge(objectName);
    }
    
    @Override
    public synchronized long getDerivedGaugeTimeStamp(ObjectName objectName) {
        return super.getDerivedGaugeTimeStamp(objectName);
    }
    
    @Deprecated
    @Override
    public synchronized String getDerivedGauge() {
        if (this.observedObjects.isEmpty()) {
            return null;
        }
        return (String)((Monitor.ObservedObject)this.observedObjects.get(0)).getDerivedGauge();
    }
    
    @Deprecated
    @Override
    public synchronized long getDerivedGaugeTimeStamp() {
        if (this.observedObjects.isEmpty()) {
            return 0L;
        }
        return ((Monitor.ObservedObject)this.observedObjects.get(0)).getDerivedGaugeTimeStamp();
    }
    
    @Override
    public synchronized String getStringToCompare() {
        return this.stringToCompare;
    }
    
    @Override
    public synchronized void setStringToCompare(String s) throws IllegalArgumentException {
        if (s == null) {
            throw new IllegalArgumentException("Null string to compare");
        }
        if (this.stringToCompare.equals(s)) {
            return;
        }
        this.stringToCompare = s;
        Iterator<Monitor.ObservedObject> iterator = this.observedObjects.iterator();
        while (iterator.hasNext()) {
            ((StringMonitor.StringMonitorObservedObject)(Monitor.ObservedObject)iterator.next()).setStatus(2);
        }
        return;
    }
    
    @Override
    public synchronized boolean getNotifyMatch() {
        return this.notifyMatch;
    }
    
    @Override
    public synchronized void setNotifyMatch(boolean notifyMatch) {
        if (this.notifyMatch == notifyMatch) {
            return;
        }
        this.notifyMatch = notifyMatch;
        return;
    }
    
    @Override
    public synchronized boolean getNotifyDiffer() {
        return this.notifyDiffer;
    }
    
    @Override
    public synchronized void setNotifyDiffer(boolean notifyDiffer) {
        if (this.notifyDiffer == notifyDiffer) {
            return;
        }
        this.notifyDiffer = notifyDiffer;
        return;
    }
    
    @Override
    public MBeanNotificationInfo[] getNotificationInfo() {
        return (MBeanNotificationInfo[])StringMonitor.notifsInfo.clone();
    }
    
    @Override
    Monitor.ObservedObject createObservedObject(ObjectName objectName) {
        StringMonitor.StringMonitorObservedObject stringMonitorObservedObject = new StringMonitorObservedObject(objectName);
        stringMonitorObservedObject.setStatus(2);
        return stringMonitorObservedObject;
    }
    
    @Override
    synchronized boolean isComparableTypeValid(ObjectName objectName, String s, Comparable<?> comparable) {
        return comparable instanceof String;
    }
    
    @Override
    synchronized void onErrorNotification(MonitorNotification monitorNotification) {
        StringMonitor.StringMonitorObservedObject stringMonitorObservedObject = (StringMonitor.StringMonitorObservedObject)this.getObservedObject(monitorNotification.getObservedObject());
        if (stringMonitorObservedObject == null) {
            return;
        }
        stringMonitorObservedObject.setStatus(2);
        return;
    }
    
    @Override
    synchronized MonitorNotification buildAlarmNotification(ObjectName objectName, String s, Comparable<?> comparable) {
        String s2 = null;
        String s3 = null;
        String s4 = null;
        StringMonitor.StringMonitorObservedObject stringMonitorObservedObject = (StringMonitor.StringMonitorObservedObject)this.getObservedObject(objectName);
        if (stringMonitorObservedObject == null) {
            return null;
        }
        if (stringMonitorObservedObject.getStatus() == 2) {
            if (stringMonitorObservedObject.getDerivedGauge().equals(this.stringToCompare)) {
                if (this.notifyMatch) {
                    s2 = "jmx.monitor.string.matches";
                    s3 = "";
                    s4 = this.stringToCompare;
                }
                stringMonitorObservedObject.setStatus(1);
            }
            else {
                if (this.notifyDiffer) {
                    s2 = "jmx.monitor.string.differs";
                    s3 = "";
                    s4 = this.stringToCompare;
                }
                stringMonitorObservedObject.setStatus(0);
            }
        }
        else if (stringMonitorObservedObject.getStatus() == 0) {
            if (stringMonitorObservedObject.getDerivedGauge().equals(this.stringToCompare)) {
                if (this.notifyMatch) {
                    s2 = "jmx.monitor.string.matches";
                    s3 = "";
                    s4 = this.stringToCompare;
                }
                stringMonitorObservedObject.setStatus(1);
            }
        }
        else if (stringMonitorObservedObject.getStatus() == 1 && !stringMonitorObservedObject.getDerivedGauge().equals(this.stringToCompare)) {
            if (this.notifyDiffer) {
                s2 = "jmx.monitor.string.differs";
                s3 = "";
                s4 = this.stringToCompare;
            }
            stringMonitorObservedObject.setStatus(0);
        }
        return new MonitorNotification(s2, this, 0L, 0L, s3, null, null, null, s4);
    }
    
    static {
        types = new String[] { "jmx.monitor.error.runtime", "jmx.monitor.error.mbean", "jmx.monitor.error.attribute", "jmx.monitor.error.type", "jmx.monitor.string.matches", "jmx.monitor.string.differs" };
        notifsInfo = new MBeanNotificationInfo[] { new MBeanNotificationInfo(StringMonitor.types, "javax.management.monitor.MonitorNotification", "Notifications sent by the StringMonitor MBean") };
    }
    
    static class StringMonitorObservedObject extends Monitor.ObservedObject
    {
        private int status;
        
        public StringMonitorObservedObject(ObjectName objectName) {
            super(objectName);
        }
        
        public final synchronized int getStatus() {
            return this.status;
        }
        
        public final synchronized void setStatus(int status) {
            this.status = status;
        }
    }
}
